@@ -601,7 +601,7 @@ attribute_get_details (const gchar  *name,
                        const gchar **out_desc)
 {
   SmartDetails *details;
-  static volatile gsize have_hash = 0;
+  static gsize have_hash = 0;
   static GHashTable *smart_details_map = NULL;
   gboolean ret;
 
@@ -1028,6 +1028,7 @@ gdu_ata_smart_get_overall_assessment (UDisksDriveAta *ata,
            * The second %s is the temperature of the drive.
            */
           s1 = g_strdup_printf (_("%s (%s)"), ret, s);
+          g_free (s);
           g_free (ret);
           ret = s1;
         }
@@ -1684,15 +1685,15 @@ gdu_ata_smart_dialog_show (GduWindow    *window,
 
   action = g_simple_action_new ("short", NULL);
   g_signal_connect (action, "activate", G_CALLBACK (on_selftest_short), data);
-  g_simple_action_group_insert (group, G_ACTION (action));
+  g_action_map_add_action (G_ACTION_MAP (group), G_ACTION (action));
 
   action = g_simple_action_new ("extended", NULL);
   g_signal_connect (action, "activate", G_CALLBACK (on_selftest_extended), data);
-  g_simple_action_group_insert (group, G_ACTION (action));
+  g_action_map_add_action (G_ACTION_MAP (group), G_ACTION (action));
 
   action = g_simple_action_new ("conveyance", NULL);
   g_signal_connect (action, "activate", G_CALLBACK (on_selftest_conveyance), data);
-  g_simple_action_group_insert (group, G_ACTION (action));
+  g_action_map_add_action (G_ACTION_MAP (group), G_ACTION (action));
 
   gtk_widget_insert_action_group (GTK_WIDGET (data->dialog), "test", G_ACTION_GROUP (group));
 
