@@ -76,8 +76,6 @@ gboolean        gdu_utils_show_confirmation (GtkWindow    *parent_window,
                                              GList        *objects,
                                              gboolean     destructive_action);
 
-gboolean gdu_utils_is_ntfs_available (UDisksClient *client);
-
 
 /* Defined by libblockdev/UDisks */
 typedef enum {
@@ -98,6 +96,11 @@ gboolean gdu_utils_can_repair (UDisksClient *client,
                                gboolean      flush,
                                gchar       **missing_util_out);
 
+gboolean gdu_utils_can_format (UDisksClient *client,
+                               const gchar  *fstype,
+                               gboolean      flush,
+                               gchar       **missing_util_out);
+
 gboolean gdu_utils_can_take_ownership (const gchar  *fstype);
 
 gboolean gdu_utils_can_check  (UDisksClient *client,
